@@ -138,7 +138,7 @@ def add_graph_generation(group):
         s, t = input.split(":", 1)
 
         s = s.strip().upper()
-        if not s.isalpha() or len(s) != 1:
+        if not (s.isalpha() and (len(s) == 1 or s == "CTERM" or s == "NTERM")):
             raise ArgumentTypeError(
                 "The amino acid which gets replaced can only be set to: [A-Z] (1 letter)! Found: '{}'".format(s)
             )
@@ -156,14 +156,16 @@ def add_graph_generation(group):
         help="Apply a fixed modification on a special aminoacid."
         " You can apply multiple fix modifications BUT only one modification per aminoacid is currently allowed."
         " The form should be '<AminoAcid>:<DeltaMass>' e.g. \"-fm 'M:15.994915'\" would indicate a"
-        " fixed oxidation of M. Note: modifications on the same aminoacid are superseeded"
+        " fixed oxidation of M. Note: modifications on the same aminoacid are superseeded."
+        " For the N- and C-Terminus use \"nterm\" or \"cterm\""
     )
     group.add_argument(
         "--variable_mod", "-vm", type=_parse_mod, action="append",
         help="Apply a variable modification on a special aminoacid."
         " You can apply multiple variable modifications BUT only one modification per aminoacid is currently allowed."
         " The form should be '<AminoAcid>:<DeltaMass>' e.g. \"-fm 'M:15.994915'\" would indicate a fixed oxidation"
-        " of M. Note: modifications on the same aminoacid are superseeded (superseeding fixed modifications"
+        " of M. Note: modifications on the same aminoacid are superseeded."
+        " For the N- and C-Terminus use \"nterm\" or \"cterm\""
     )
 
     # Flag to check if generated graphs are correctly generated
@@ -176,7 +178,7 @@ def add_graph_generation(group):
     # Arguments for graph processing/digestion
     group.add_argument(
         "--digestion", "-d", type=str.lower, action="append",
-        choices=["trypsin", "skip", "full"],
+        choices=["gluc", "trypsin", "skip", "full"],
         help="Set the digestion method. The full digestion cleaves at every edge, which can be useful for retrieving "
         "all possible peptides with arbitrary cutting points. The digestion method skip skips the digestion "
         "completely. You can use multiple digestions at once! Default: Trypsin"
@@ -558,7 +560,7 @@ def add_sqlite_peptide_export(group):
     # TODO
     group.add_argument(
         "--export_peptide_sqlite", "-epepsqlite", default=False, action="store_true",
-        help="Set this flag to export peptides (specifically paths) to a postgresql server."
+        help="Set this flag to export peptides (specifically paths) to a sqlite server."
         "NOTE: This will try to create the tables 'accessions' and 'peptides' on a specified database."
         " Make sure the database in which the data should be saved also exists. If problems occur, try "
         "to delete the generated tables and retry again."
@@ -652,7 +654,7 @@ def add_trie_peptide_export(group):
 def add_citus_peptide_export(group):
     group.add_argument(
         "--export_peptide_citus", "-epepcit", default=False, action="store_true",
-        help="Set this flag to export peptides (specifically paths) to a postgresql server."
+        help="Set this flag to export peptides (specifically paths) to a postgresql-citus server."
         "NOTE: This will try to create the tables 'accessions' and 'peptides' on a specified database."
         " Make sure the database in which the data should be saved also exists. If problems occur, try "
         "to delete the generated tables and retry again."
